@@ -14,33 +14,20 @@ end
 function ch_item_wieldable(it)
     -- We only need to check for unusual cases - basic matching is handled
     -- by Crawl itself.
-    local spells = make_hash( you.spells() )
-
-    if (spells["Sublimation of Blood"] or spells["Simulacrum"])
-            and food.ischunk(it)
-    then
-        return true
-    end
-
-    if spells["Sublimation of Blood"]
-            and (string.find( it.name("a"), " potions? of blood") or
-                 string.find( it.name("a"), " potions? of coagulated blood"))
-    then
-        return true
-    end
+    local spells = make_hash(you.spells())
 
     if spells["Sandblast"]
             and it.class(true) == "missile"
-            and (string.find( it.name("a"), " stones?" )
-                 or string.find( it.name("a"), " large rocks?" )
-                    and (you.race() == "Troll" or you.race() == "Ogre"))
+            and (string.find(it.name("a"), " stones?")
+                 or string.find(it.name("a"), " large rocks?")
+                    and (you.race() == "Troll" or you.race() == "Ogre" or you.race() == "Formicid"))
     then
         return true
     end
 
     if spells["Sticks to Snakes"]
             and it.class(true) == "missile"
-            and string.find( it.name("a"), " arrows?" )
+            and string.find(it.name("a"), " arrows?")
     then
         return true
     end
